@@ -3,7 +3,7 @@ import logging
 from collections import defaultdict
 from dataclasses import dataclass
 from typing import List, Dict, Type, Union, Optional
-from async_tools.async_initable import AsyncInitable
+from async_tools import AsyncInitable
 from dict_caster.extras import to_list
 
 from .elements.aggregation_function import AggregationFunction
