@@ -140,3 +140,7 @@ class Table(TableBase):
     @classmethod
     def get_table_engine(cls) -> TableEngine:
         return cls.__table_engine__
+
+    @classmethod
+    def to_sql(cls) -> str:
+        return cls.get_table_engine().construct_from_sql(cls)
